$wnd.rstudio.runAsyncCallback3("function Pxi(a){this.a=a}\nfunction Rxi(a){this.a=a}\nfunction $xi(a){this.a=a}\nfunction eve(a,b){var c;for(c=0;c<a.q.a.length;c++){if(Hjd(a.q,c).bP==b){Txe(a.t,BLd(c));break}}}\nfunction Oxi(a,b){this.c=a;this.b=chi(a.c,z4n,A4n,B4n,Csn).dH();this.a=chi(a.c,C4n,D4n,E4n,F4n).dH();xi(b,new Pxi(this),$D?$D:($D=new tB))}\nfunction Mxi(a){var b;b=Nxi(a,'weaving Rnw files',a.b,chi(a.c.c,z4n,A4n,B4n,Csn));b||Nxi(a,'LaTeX typesetting',a.a,chi(a.c.c,C4n,D4n,E4n,F4n))}\nfunction Kxi(a,b,c){var d;d=tsi(a.b.a);jve(d,Dji(nDg((Rqf(),Qqf).a)));!!b&&eve(d,b);pve(d,c);ene(d,true);new Oxi(a,d);(Cwf()||!!$wnd.remoteDesktop)&&Gwf()}\nfunction Wxi(a){try{if(a.c<0)return;!a.a.a&&(a.a.a=FEi(a.a.b.a));switch(a.c){case 1:Kxi(a.a.a,null,true);break;case 2:Kxi(a.a.a,a.b[0],iKd(a.b[1]));}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nfunction Nxi(a,b,c,d){if(wK(c)!==wK(d.dH())&&wK(d.qr())!==wK(d.dH())){I2d(2,'Project Option Unchanged','You changed the global option for '+b+yqn+d.dH()+', however the current project is still configured to use '+d.qr()+'.\\n\\nDo you want to edit the options for the current project as well?',new Rxi(a),true);return true}else{return false}}\nZ0c(2798,1,{},Oxi);var IRb=CKd(2798);Z0c(2799,1,Ton,Pxi);_.so=function Qxi(a){Mxi(this.a)};var GRb=CKd(2799);Z0c(2800,1,yrn,Rxi);_.gn=function Sxi(){z8d(this.a.c.a.hh)};var HRb=CKd(2800);Z0c(621,1,gSn);_.en=function Zxi(){Wxi((new $xi(this)).a)};Z0c(2852,1,Zqn,$xi);_.gn=function _xi(){Wxi(this.a)};var JRb=CKd(2852);Mhn(fm)(3);\n//# sourceURL=rstudio-3.js\n")
