$wnd.rstudio.runAsyncCallback17("function Jlk(a){this.a=a}\nfunction Duk(a){this.a=a}\nfunction Fuk(a,b){this.a=a;this.b=b}\nfunction Bul(a,b){this.a=a;this.b=b}\nfunction Xul(a,b){this.a=a;this.b=b}\nfunction Gtm(a,b){Ftm();this.b=a;this.a=b}\nfunction ufm(a,b){gLg(a.u,b)}\nfunction Kgl(a,b){ufm(a.ub,b)}\nfunction rkk(a){KNf(a.n,a.c,null)}\nfunction skk(a){KNf(a.n,a.g,null)}\nfunction Fkk(a){Wkk(a.o,a.g,Nzo,null)}\nfunction Kkk(a){Wkk(a.o,a.g,'next',null)}\nfunction Mkk(a){Wkk(a.o,a.g,'prev',null)}\nfunction Nkk(a){Wkk(a.o,a.g,'refresh',null)}\nfunction tkk(a){KNf(a.n,a.g+'?print-pdf',null)}\nfunction Pdg(a){return {items:a}}\nfunction Zpk(a,b){var c;c=a;Rgl(c,b.a)}\nfunction Ypk(a,b){en((Zm(),Ym),new Fuk(b,a))}\nfunction Dgl(a,b){en((Zm(),Ym),new Xul(a,b))}\nfunction Rgl(a,b){wxm(a.w,PWn,false)?_el(a,new Bul(a,b)):jzl(a._,b)}\nfunction uxf(a){$wnd.desktop.setPresentationUrl(a)}\nfunction gLg(a,b){a.d.navigateToPresentationEditorLocation(b)}\nfunction lkk(a,b){mMd(b.substr(0,4),nmn)||(b=qKh(a.p,b));return b}\nfunction qkk(a){!!a.b&&Bzf(a.k,new Gtm((Zle(),pme(a.b.source_file,false,-1,0)),Jdg(a.d,a.a,a.e)),false)}\nfunction Kdg(a,b){var c,d,e,f;b==-1&&(b=a.auto_slide_level);f=Idg(a,b,true);for(c=0;c<f.length;c++){e=f[c];for(d=0;d<e.items.length;d++){if(mMd(e.items[d].type,eNn))return c}}return 0}\nfunction Jdg(a,b,c){var d,e,f,g,h;c==-1&&(c=b.auto_slide_level);h=Idg(b,c,false);if(a<h.length){g=h[a];zl(g.items,Mdg(g.items[0].row))}e=[];for(d=0;d<h.length;d++){g=h[d];for(f=0;f<g.items.length;f++){xl(e,g.items[f])}}return Ldg(e,b.auto_slide_level)}\nfunction jzl(a,b){var c,d,e,f,g,h,i;e=izl(a).items;d=[];for(g=0;g<e.length;g++){h=e[g];mMd(h.type,eNn)||(d[d.length]=h,undefined)}c=-1;i=b.items;for(f=0;f<i.length;f++){if(mMd(i[f].type,eNn)){c=f;break}}if(c>=0){h=d[c];!!h&&mZk(a.a,Czm(h.row,0),true)}}\nfunction Idg(a,b,c){var d,e,f,g,h,i;i=[];g=a.items;for(d=0;d<g.length;d++){f=g[d];e=i.length==0||mMd(f.type,Mjn)||mMd(f.type,'hr')||mMd(f.type,jjn)&&f.level<=b;if(e){h=Pdg([]);xl(h.items,f);i[i.length]=h}else (c||!mMd(f.type,eNn))&&xl(i[i.length-1].items,f)}return i}\nfunction ukk(a,b){var c,d;c=b.a;d=lkk(a,c.url);a.o=Kdg(b.a.editor_state,b.a.slide_level);a.o==0&&a.d!=0&&(a.o=a.d);FBi(a.j);if(!mMd(d,a.g)||!a.j.o){a.g=d;a.c=d;a.b=c.quarto_navigation;a.a=c.editor_state;a.e=c.slide_level;(Cwf()||!!$wnd.remoteDesktop)&&uxf(a.g);Jkk(a.j,a.g,a.b)}else{Nkk(a.j)}}\nfunction Jkk(a,b,c){var d;(Cwf()||!!$wnd.remoteDesktop)&&(t6d(b)?(Oh(a.d).removeAttribute(_Mn),undefined):(Oh(a.d).setAttribute(_Mn,oVo),undefined));a.b=b;a.o=null;a.g=null;d=Qh(a.d);d>0&&yi(a,new Oje(xK(d*0.6666666666666666)+((a.K?Ph(a.K):0)+(a.O?Ph(a.O):0))));Grd(a.d,a.b);c.is_website?eGh(a.i):dGh(a.i,c.source_file,c.output_file);Bff(a.p)}\nfunction Flk(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=imk(a.a.b.a);Dwi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.oH();break;case 2:a.a.a.J.pH();break;case 3:qkk(a.a.a);break;case 4:Fkk(a.a.a.j);break;case 5:Kkk(a.a.a.j);break;case 6:rkk(a.a.a);break;case 7:skk(a.a.a);break;case 8:Mkk(a.a.a.j);break;case 9:tkk(a.a.a);break;case 10:ukk(a.a.a,a.b[0]);break;case 11:Nkk(a.a.a.j);break;case 12:a.a.a.J.qH();break;case 13:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nZ0c(297,1,gSn);_.en=function Ilk(){Flk((new Jlk(this)).a)};Z0c(6309,1,Zqn,Jlk);_.gn=function Klk(){Flk(this.a)};var Zic=CKd(6309);Z0c(3053,1,Uqn,Duk);_.Zt=function Euk(a){Ypk(this.a,a)};var xmc=CKd(3053);Z0c(3052,1,mkn,Fuk);_.gn=function Guk(){Zpk(this.a,this.b)};var ymc=CKd(3052);Z0c(4273,1,Zqn,Bul);_.gn=function Cul(){Dgl(this.a,this.b)};var JAc=CKd(4273);Z0c(4272,1,mkn,Xul);_.gn=function Yul(){Kgl(this.a,this.b)};var UAc=CKd(4272);Z0c(3097,Vln,{},Gtm);_.Vn=function Htm(a){var b,c;b=(c=N3f(a.k,this.b),!!c&&qK(c,79)?c:(G3f(),B3f));wyk(a.b,this.b,b,new Duk(this))};_.Xn=function Jtm(){return Etm};_.Wn=function Itm(){return Etm};var CPc=CKd(3097);Mhn(fm)(17);\n//# sourceURL=rstudio-17.js\n")
