$wnd.rstudio.runAsyncCallback16("function wjk(a){this.a=a}\nfunction Vhk(a,b){this.a=a;this.b=b;Mle.call(this)}\nfunction yhk(a,b){a.a=b;Lik(a.p,uhk(a,null),a.a.file_path)}\nfunction Ahk(a,b){b.slide_index==0&&FBi(a.p);a.a=b;Lik(a.p,uhk(a,null),a.a.file_path)}\nfunction Ghk(a){ghf('Opening Presentation...',qzd());Bzf(a.c,new wBf,false)}\nfunction vhk(a){var b;b=NOf(new OOf(0,'Closing Presentation...'));sJh(a.n,new Vhk(a,b))}\nfunction sJh(a,b){GOh(a,pTn,'close_presentation_pane',new NH,b)}\nfunction Fhk(a){var b;a.J.qH();!!a.a&&a.a.active&&(b=Mie(Oh(a.p.d).contentWindow),!(!mMd(Irn,b)&&!mMd('javascript:void(0)',b)))&&yhk(a,a.a)}\nfunction sjk(a){var b,c;try{if(a.c<0)return;if(!a.a.a){a.a.a=gkk(a.a.b.a);Dwi(a.a,a.a.a)}switch(a.c){case 1:vhk((c=a.a.a,a.b[0],c));break;case 2:Ahk(a.a.a,a.b[0]);break;case 3:a.a.a.J.oH();break;case 4:a.a.a.J.pH();break;case 5:Fhk(a.a.a);break;case 6:Ghk((b=a.a.a,a.b[0],b));break;case 7:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nZ0c(6779,32,{},Vhk);_.ev=function Xhk(a){var b;Bzf((b=this,a,b).a.c,new wBf,false)};_.dv=function Whk(a){eOf(this.b,a.a?a.a.c:a.d)};var ijc=CKd(6779);Z0c(455,1,gSn);_.en=function vjk(){sjk((new wjk(this)).a)};Z0c(6306,1,Zqn,wjk);_.gn=function xjk(){sjk(this.a)};var Hjc=CKd(6306);Mhn(fm)(16);\n//# sourceURL=rstudio-16.js\n")
