$wnd.rstudio.runAsyncCallback7("function SZj(a){this.a=a}\nfunction aZj(a,b){this.a=a;this.b=b}\nfunction YYj(a,b){b==null?u9d(a,oLo):u9d(a,b)}\nfunction lZj(a,b){yi(a.d,new _je(false));cZj(a.d,b,0)}\nfunction UMh(a,b){GOh(a,pTn,'markers_tab_closed',new NH,b)}\nfunction ZYj(a,b){var c,d,e,f,g,h,i;d=a.q;Rud(d.o);for(g=b,h=0,i=g.length;h<i;++h){f=g[h];c=new aZj(a,f);e=new B2c(z2c(new A2c,f).a.a);Ydf(d,new Yvd(e,c))}}\nfunction cZj(a,b,c){var d;Qng(a.b);YYj(a.c,null);ZYj(a.c,DJ(yJ(qY,1),xin,2,6,[]));if(b.markers){d=b.markers;Ung(a.b,null,d.base_path,d.markers,c,false);ZYj(a.c,vre(b.names));YYj(a.c,d.name)}}\nfunction kZj(a,b){var c,d,e,f,g;g=b.a.markers_state;if(g.markers){yi(a.d,new _je(true));cZj(a.d,b.a.markers_state,b.a.auto_select);e=g.markers;if(e){d=e.markers;if(d.length>0){f=null;c=b.a.auto_select;c==1?(f=d[0]):c==2&&(f=Cng(d));!!f&&H3f(a.b,(Zle(),pme(f.path,false,-1,0)),v1d(f.line,f.column),false)}}}else{yi(a.d,new Uje)}}\nfunction OZj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=_Zj(a.a.b.a);Dwi(a.a,a.a.a)}switch(a.c){case 1:jZj(a.a.a);break;case 2:a.a.a.J.oH();break;case 3:a.a.a.J.pH();break;case 4:UMh(a.a.a.c,new etf);break;case 5:kZj(a.a.a,a.b[0]);break;case 6:a.a.a.J.qH();break;case 7:a.a.a.J.rH();break;case 8:lZj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nZ0c(7462,1,mkn,aZj);_.gn=function bZj(){tE(this.a,this.b)};var idc=CKd(7462);Z0c(427,1,gSn);_.en=function RZj(){OZj((new SZj(this)).a)};Z0c(6126,1,Zqn,SZj);_.gn=function TZj(){OZj(this.a)};var vdc=CKd(6126);Mhn(fm)(7);\n//# sourceURL=rstudio-7.js\n")
