$wnd.rstudio.runAsyncCallback9("function GEj(a){this.a=a}\nfunction yDj(a){a.J.qH();T0e(a.j.o)}\nfunction wDj(a){FBi(a.j);qNf(a.a,'Load History','loadhistory')}\nfunction xDj(a){FBi(a.j);vNf(a.a,'Save History As','.Rhistory',false,'savehistory')}\nfunction CEj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=jFj(a.a.b.a);Dwi(a.a,a.a.a)}switch(a.c){case 1:a.a.a.J.oH();break;case 2:a.a.a.J.pH();break;case 3:wDj(a.a.a);break;case 4:xDj(a.a.a);break;case 5:yDj(a.a.a);break;case 6:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nZ0c(507,1,gSn);_.en=function FEj(){CEj((new GEj(this)).a)};Z0c(6225,1,Zqn,GEj);_.gn=function HEj(){CEj(this.a)};var k8b=CKd(6225);Mhn(fm)(9);\n//# sourceURL=rstudio-9.js\n")
