$wnd.rstudio.runAsyncCallback23('function _$j(a){this.a=a}\nfunction s$j(a,b){this.a=a;this.b=b}\nfunction e$j(a,b){a.n?K2d(4,\'Stop R Markdown Rendering\',"The rendering of \'"+a.i+"\' is in progress. Do you want to terminate and close the tab?",false,new s$j(a,b),null,null,KPn,srn,true):b.gn()}\nfunction X$j(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=b_j(a.a.b.a);Dwi(a.a,a.a.a)}switch(a.c){case 1:uGi(a.a.a,a.b[0]);break;case 2:e$j(a.a.a,a.b[0]);break;case 3:f$j(a.a.a);break;case 4:a.a.a.J.oH();break;case 5:a.a.a.J.pH();break;case 6:g$j(a.a.a,a.b[0]);break;case 7:h$j(a.a.a,a.b[0]);break;case 8:i$j(a.a.a,a.b[0]);break;case 9:j$j(a.a.a,a.b[0]);break;case 10:a.a.a.J.qH();break;case 11:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nZ0c(6858,1,yrn,s$j);_.gn=function t$j(){k$j(this.a);this.b.gn()};var Edc=CKd(6858);Z0c(314,1,gSn);_.en=function $$j(){X$j((new _$j(this)).a)};Z0c(6344,1,Zqn,_$j);_.gn=function a_j(){X$j(this.a)};var Ndc=CKd(6344);Mhn(fm)(23);\n//# sourceURL=rstudio-23.js\n')
