$wnd.rstudio.runAsyncCallback27("function _Yd(){}\nfunction CHj(){}\nfunction dIj(a){this.a=a}\nfunction vHj(a,b){pKj(a.c,b)}\nfunction CYd(a){var b;vYd(a);b=0;while(a.a.Pt(new _Yd)){b=y0c(b,1)}return b}\nfunction ZKj(a){var b,c,d;d=new Tjd;for(c=new yre((new wre(Lce(a.i))).a);c.b.length>c.a;){b=c.b[c.a++];Djd(d,a.i[b])}return d}\nfunction oHj(a,b){var c,d;c=ZKj(LLj(a.d.a));if(c.a.length==0){EOj(a.b,false);b.gn()}d=CYd(DYd(new IYd(null,new RVd(c)),new CHj));if(z0c(d,0)>0){p0c().yC(1,'Local Jobs Still Running','The Jobs tab cannot be closed while there '+(z0c(d,1)>0?'are unfinished local jobs.':'is an unfinished local job.')+'\\n\\nWait until all local jobs have completed.').zC();return}EOj(a.b,false);b.gn()}\nfunction _Hj(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=SLj(a.a.b.a);Dwi(a.a,a.a.a)}switch(a.c){case 1:oHj(a.a.a,a.b[0]);break;case 2:pHj(a.a.a);break;case 3:a.a.a.J.oH();break;case 4:a.a.a.J.pH();break;case 5:qHj(a.a.a,a.b[0]);break;case 6:rHj(a.a.a,a.b[0]);break;case 7:sHj(a.a.a,a.b[0]);break;case 8:tHj(a.a.a,a.b[0]);break;case 9:uHj(a.a.a,a.b[0]);break;case 10:a.a.a.J.qH();break;case 11:a.a.a.J.rH();break;case 12:vHj(a.a.a,a.b[0]);}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nZ0c(2119,1,{},_Yd);_.Tt=function aZd(a){zYd()};var j$=CKd(2119);Z0c(6871,1,{},CHj);_.Ut=function DHj(a){return a.type==1&&a.state==2};var Y8b=CKd(6871);Z0c(317,1,gSn);_.en=function cIj(){_Hj((new dIj(this)).a)};Z0c(6365,1,Zqn,dIj);_.gn=function eIj(){_Hj(this.a)};var d9b=CKd(6365);Mhn(fm)(27);\n//# sourceURL=rstudio-27.js\n")
