$wnd.rstudio.runAsyncCallback15("function hIi(){}\nfunction fIi(a){this.a=a}\nfunction kIi(a){this.a=a}\nfunction mIi(a){this.a=a}\nfunction mJi(a){this.a=a}\nfunction CHi(a){this.a=a}\nfunction jYf(a){this.a=a}\nfunction hHi(a){tHi(a,new kIi(a))}\nfunction mHi(a){HWf(a.b,new mIi(a))}\nfunction lHi(a){Spk(a.n,new fIi(a),new hIi,gQn)}\nfunction oHi(a){Spk(a.n,new aIi(a,jtn,false),new cIi,vWn)}\nfunction qHi(a,b){Bzf(a.d,new a$i(b,true),false)}\nfunction SWf(a,b){(rZd(b),b)&&sHi(a.a,iWo,'')}\nfunction EHi(a,b){this.a=a;this.b=b;qPf.call(this)}\nfunction jIi(a,b){qHi(a.a,'devtools::load_all(\"'+b+'\")')}\nfunction YJh(a,b){GOh(a,pTn,'devtools_load_all_path',new NH,b)}\nfunction tHi(a,b){a.c!=null?jIi(b,a.c):YJh(a.j,new EHi(a,b))}\nfunction nHi(a){a.J.qH();en((Zm(),Ym),new CHi(a))}\nfunction AHi(){pOf.call(this,'Terminating Build...')}\nfunction HWf(a,b){tWf(a,hWo,hWo,KYf(a.i.b.package_dependencies,'roxygen'),gWf(a,'roxygen'),false,new jYf(b))}\nfunction eHi(a,b){var c,d;vQf(a.q.d,null);d=b.outputs;for(c=0;c<d.length;c++)DGi(a.q,d[c]);b.errors.length>0&&CGi(a.q,b.errors_base_dir,b.errors,false,0,true,b.type);b.running?W8d(a.a.Rj,true,false):uQf(a.q.d);_Ye(a.q.d.c.c)}\nfunction iJi(a){try{if(a.c<0)return;if(!a.a.a){a.a.a=ZJi(a.a.b.a);Dwi(a.a,a.a.a)}switch(a.c){case 1:eHi(a.a.a,a.b[0]);break;case 2:a.a.a.J.oH();break;case 3:a.a.a.J.pH();break;case 4:sHi(a.a.a,ODo,'');break;case 5:sHi(a.a.a,'build-binary-package','');break;case 6:sHi(a.a.a,'build-source-package','');break;case 7:sHi(a.a.a,'check-package','');break;case 8:sHi(a.a.a,'clean-all','');break;case 9:lHi(a.a.a);break;case 10:sHi(a.a.a,PDo,'');break;case 11:mHi(a.a.a);break;case 12:nHi(a.a.a);break;case 13:oHi(a.a.a);break;case 14:IPh(a.a.a.j,new AHi);break;case 15:sHi(a.a.a,'test-package','');break;case 18:a.a.a.J.rH();}}finally{a.c<=0&&a.b[0]!=null&&a.b[0].gn()}}\nvar hWo='Building package documentation',iWo='roxygenize-package';Z0c(2211,1,Uqn,jYf);_.Zt=function kYf(a){SWf(this.a,a)};var Gkb=CKd(2211);Z0c(6763,379,{},AHi);_.Wm=function BHi(a){(rZd(a),a)||p0c().yC(3,'Error Terminating Build','Unable to terminate build. Please try again.').zC()};var tUb=CKd(6763);Z0c(6764,1,Zqn,CHi);_.gn=function DHi(){_Ye(this.a.q.d.c.c)};var uUb=CKd(6764);Z0c(6765,54,{},EHi);_.ev=function FHi(a){this.a.c=a;jIi(this.b,this.a.c)};var vUb=CKd(6765);Z0c(6756,1,Zqn,fIi);_.gn=function gIi(){hHi(this.a)};var LUb=CKd(6756);Z0c(6757,1,Zqn,hIi);_.gn=function iIi(){};var MUb=CKd(6757);Z0c(6755,1,Uqn,kIi);_.Zt=function lIi(a){jIi(this,a)};var NUb=CKd(6755);Z0c(6758,1,Zqn,mIi);_.gn=function nIi(){sHi(this.a,iWo,'')};var OUb=CKd(6758);Z0c(251,1,gSn);_.en=function lJi(){iJi((new mJi(this)).a)};Z0c(6290,1,Zqn,mJi);_.gn=function nJi(){iJi(this.a)};var iVb=CKd(6290);Mhn(fm)(15);\n//# sourceURL=rstudio-15.js\n")
